pub enum Part {
Text(String),
Escape,
Newline,
Style(StyleKind, bool),
Color(Color, bool),
Emote(EmoteKind),
}Expand description
A single element of parsed sillycode markup.
Variants
Text(String)
Plain text content.
Escape
Escape backslash character.
Newline
Line break character.
Style(StyleKind, bool)
Style formatting toggle, enable or disable, each effect is independent.
Color(Color, bool)
Color formatting toggle, enable or disable, acts as a stack.
Emote(EmoteKind)
Emoticon image.